==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Fayl bələdçisində göstərmək</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Jurnalı silmək</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Təzələmək</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Jurnalı təmizləmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Təsdiq etmək</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Hamısı</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Bugün</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 gün</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 həftə</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 ay</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 ay</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">İxrac</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>İxrac</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Hamısı</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Gözlənilməz hal </translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Xəbərdarlıq siqnalı</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Xəta</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Xəbərdarlıq</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Bildiriş</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Məlumat</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Xəta sazlama</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Giriş</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Önyükləyici</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Söndürmək</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritik</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>İz</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>MƏTN (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>İxrac olunur...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>İxrac uğurlu oldu</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>İxrac baş tutmadı</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Faylı ixrac etmək</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Dövr:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Səviyyə:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Tətbiq siyahısı:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Vəziyyət:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Hadisənin növü:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>İstifadəçi:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Əməl:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>İstifadəçi adı:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Ön yüklənmənin yazılması</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Söndürülmənin yazılması</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Girişin yazılması</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Xəbərdarlıq</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Xəta sazlama</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Məlumat</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Xəta</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Gözlənilməz hal </translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Xəbərdarlıq siqnalı</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Bildiriş</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>İz</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritik</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Jurnal faylı böşdur</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Jurnal İcmalı</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Jurnal İcmalı, sistem jurnallarına baxmaq üçün istifadəsi rahat alətdir.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Axtarış nəticələri yoxdur</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Axtarış</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Səviyyə</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proses</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Tarix və Vaxt</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Məlumat</translation>
    </message>
    <message>
        <source>User</source>
        <translation>İstifadəçi</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Mənbə</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Əməl</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Vəziyyət</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Hadisənin növü</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Səviyyə:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proses:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Tarix və Vaxt:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Məlumat:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Sıfır</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>İstifadəçi:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Tarix və Vaxt</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Sistem jurnalı</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Nüvə jurnalı</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Önyükləyici jurnalı</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg jurnalı</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin jurnalı</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg jurnalı</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Tətbiq jurnalı</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Önyükləyici-Söndürmə hadisəsi</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf jurnalı</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Fayl bələdçisində göstərmək</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Jurnalı silmək</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Təzələmək</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Jurnalı təmizləmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Təsdiq etmək</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Hamısı</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Bugün</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 gün</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 həftə</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 ay</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 ay</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>İxrac</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Hamısı</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Gözlənilməz hal </translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Xəbərdarlıq siqnalı</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Xəta</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Xəbərdarlıq</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Bildiriş</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Məlumat</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Xəta sazlama</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Giriş</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Önyükləyici</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Söndürmək</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritik</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>İz</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Kimlik doğrulaması</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Girişə ixtiyari nəzarət</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Girişə mütləq nəzarət</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Uzaqdan idarəetmə</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Sənədin təftişi</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Digər</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>MƏTN (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>İxrac olunur...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>İxrac uğurlu oldu</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>İxrac baş tutmadı</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Faylı ixrac etmək</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Dövr:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Səviyyə:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Vəziyyət:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Hadisənin növü:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>İstifadəçi:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Əməl:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>İstifadəçi adı:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Ön yüklənmənin yazılması</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Söndürülmənin yazılması</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Girişin yazılması</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Təftişin növü</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Xəbərdarlıq</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Xəta sazlama</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Məlumat</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Xəta</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Gözlənilməz hal </translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Xəbərdarlıq siqnalı</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Bildiriş</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>İz</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritik</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Jurnal faylı böşdur</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Jurnal İcmalı</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Jurnal İcmalı, sistem jurnallarına baxmaq üçün istifadəsi rahat alətdir.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Axtarış nəticələri yoxdur</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Axtarış</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Səviyyə</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proses</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Tarix və Vaxt</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Məlumat</translation>
    </message>
    <message>
        <source>User</source>
        <translation>İstifadəçi</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Mənbə</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Əməl</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Vəziyyət</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Hadisənin növü</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>İstifadəçi adı</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Səviyyə:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proses:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Tarix və Vaxt:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Məlumat:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Sıfır</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>İstifadəçi:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Fayl adı</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Dəyişdirilmə vaxtı</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Tarix və Vaxt</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Sistem jurnalı</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Nüvə jurnalı</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Önyükləyici jurnalı</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg jurnalı</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin jurnalı</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg jurnalı</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Tətbiq jurnalı</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Önyükləyici-Söndürmə hadisəsi</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf jurnalı</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Başqa jurnal</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Fərdi jurnal</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Təftiş jurnalı</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Buna baxmaq üçün icazəniz yoxdur</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Yenilənmə aralığı</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 san</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 dəq</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 dəq</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Yeniləməmək</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Hamısını ixrac edin</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>İndi yeniləyin</translation>
    </message>
</context>
</TS>
